import request from '@/utils/request'
export function getAppShopIndex(data = {}) {
	return request({
		url: "/app/shop/index",
		headers: {
			isToken: true
		},
		method: 'post',
		data,
		timeout: 20000
	})
}


export function getAppCp1Buy(data = {}) {
	return request({
		url: "/app/shop/shuxue/buy",
		headers: {
			isToken: true
		},
		method: 'post',
		data,
		timeout: 20000
	})
}

export function getAppCp1Info(data = {}) {
	return request({
		url: "/app/shop/shuxue/info",
		headers: {
			isToken: true
		},
		method: 'post',
		data,
		timeout: 20000
	})
}

export function getAppCp2Buy(data = {}) {
	return request({
		url: "/app/shop/jisuan/buy",
		headers: {
			isToken: true
		},
		method: 'post',
		data,
		timeout: 20000
	})
}

export function getAppCp2Info(data = {}) {
	return request({
		url: "/app/shop/jisuan/info",
		headers: {
			isToken: true
		},
		method: 'post',
		data,
		timeout: 20000
	})
}

export function getAppCp3Buy(data = {}) {
	return request({
		url: "/app/shop/pindu/buy",
		headers: {
			isToken: true
		},
		method: 'post',
		data,
		timeout: 20000
	})
}

export function getAppCp3Info(data = {}) {
	return request({
		url: "/app/shop/pindu/info",
		headers: {
			isToken: true
		},
		method: 'post',
		data,
		timeout: 20000
	})
}

export function getAppCp4Buy(data = {}) {
	return request({
		url: "/app/shop/danci/buy",
		headers: {
			isToken: true
		},
		method: 'post',
		data,
		timeout: 20000
	})
}

export function getAppCp4Info(data = {}) {
	return request({
		url: "/app/shop/danci/info",
		headers: {
			isToken: true
		},
		method: 'post',
		data,
		timeout: 20000
	})
}

export function orderPayAli(data = {}) {
	return request({
		url: "/app/order/pay/ali",
		headers: {
			isToken: true
		},
		method: 'post',
		data,
		timeout: 20000
	})
}



export function orderPayWx(data = {}) {
	return request({
		url: "/app/order/pay/wx",
		headers: {
			isToken: true
		},
		method: 'post',
		data,
		timeout: 20000
	})
}

export function orderPayApple(data = {}) {
	return request({
		url: "/app/order/pay/apple",
		headers: {
			isToken: true
		},
		method: 'post',
		data,
		timeout: 20000
	})
}



export function orderCheck(data = {}) {
	return request({
		url: "/app/order/check",
		headers: {
			isToken: true
		},
		method: 'post',
		data,
		timeout: 20000
	})
}

export function orderList(data = {}) {
	return request({
		url: "/app/order/list",
		headers: {
			isToken: true
		},
		method: 'post',
		data,
		timeout: 20000
	})
}